==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/dochazka/omezenidochazkybrowser.php <==
<?php
/**
 * stanislav.elbl, 22.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;


class OmezeniDochazkyBrowser extends RonPortalBrowser
{
    function __construct($database)
    {
        parent::__construct($database, 'omezenidochazky');

        $this->title = TextManager::_('Omezeni_dochazky');
        $this->sqlFromPart =
            'VysledekOmezeni, TypCasoveSlozkyMzdy';

        $this->sqlWherePart =
            'TypCasoveSlozkyMzdy.Kod = VysledekOmezeni.CasovaSlozkaMzdy';

        $this->defaultSort = 1;

        $this ->sqlSelectPart =
            'CasovaSlozkaMzdy, TypCasoveSlozkyMzdy.Popis, PocatekObdobi, KonecObdobi, HodinyMin, HodinyMax';

        $this->code = 'browseromezenidochazky';

        $this->addField()
            ->setSqlFieldIndex(0) ->setSqlFieldName('CasovaSlozkaMzdy')
            ->setCode('col-kod')
            ->setHeaderText('Kod') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldIndex(1) ->setSqlFieldName('TypCasoveSlozkyMzdy.Popis')
            ->setCode('col-popis')
            ->setHeaderText('Casova_slozka') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldIndex(2) ->setSqlFieldName('PocatekObdobi')
            ->setCode('col-pocatekobdobi')
            ->setHeaderText('Pocatek') ->setFormat('date') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldIndex(3) ->setSqlFieldName('KonecObdobi')
            ->setCode('col-konecobdobi')
            ->setHeaderText('Konec') ->setFormat('date') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldIndex(4) ->setSqlFieldName('HodinyMin')
            ->setCode('col-hodinymin')
            ->setHeaderText('Chybi') ->setFormat('number1') ->setAlign('center') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldIndex(5) ->setSqlFieldName('HodinyMax')
            ->setCode('col-hodinymax')
            ->setHeaderText('Prekroceno') ->setFormat('number1') ->setAlign('center') ->setOrdering(1);
    }


    function setFilterForm()
    {
        parent::setFilterForm();
        $this->filterForm->osobyFiltr = 'PracovniPomer.ZpracovatDochazku = 1';
        $this ->filterForm ->downloadFotoOsobyUrl = '?menuid=editace&action=foto&idpp=';
        $this ->filterForm ->nastavAkciGet('omezenidochazky');
    }


    function load($sqlFilter = '')
    {
        parent::load($sqlFilter);
        $this ->browserUrl =
            '?menuid=omezenidochazky&idpp=' . (int)$this ->filterForm ->vybranaOsoba . '&obdobi=' . DateUtils::dateToUrlString($this ->filterForm ->vybraneObdobiOd);
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        return new SqlStatement(
            ' RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND DatumNastupu = ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->vybranaOsobaDatumNastupu)) .
            ' AND PocatekObdobi <= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->vybraneObdobiDo)) .
            ' AND KonecObdobi >= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->vybraneObdobiOd)),
            $params);
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/dochazka/omezenidochazkybrowser.php <==
<?php
/**
 * stanislav.elbl, 22.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;


class OmezeniDochazkyBrowser extends RonPortalBrowser
{
    function __construct($database)
    {
        parent::__construct($database, 'omezenidochazky');

        $this->title = TextManager::_('Omezeni_dochazky');
        $this->sqlFromPart =
            'VysledekOmezeni, TypCasoveSlozkyMzdy';

        $this->sqlWherePart =
            'TypCasoveSlozkyMzdy.Kod = VysledekOmezeni.CasovaSlozkaMzdy';

        $this->code = 'browseromezenidochazky';

        $this->addField()
            ->setSqlFieldName('CasovaSlozkaMzdy')
            ->setCode('col-kod')
            ->setHeaderText('Kod') ->setOrdering(true);

        $this->defaultSort = 'col-kod';

        $this->addField()
            ->setSqlFieldName('TypCasoveSlozkyMzdy.Popis')
            ->setCode('col-popis')
            ->setHeaderText('Casova_slozka') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('PocatekObdobi')
            ->setCode('col-pocatekobdobi')
            ->setHeaderText('Pocatek') ->setFormat('date') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('KonecObdobi')
            ->setCode('col-konecobdobi')
            ->setHeaderText('Konec') ->setFormat('date') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('HodinyMin')
            ->setCode('col-hodinymin')
            ->setHeaderText('Chybi') ->setFormat('number1') ->setAlign('center') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('HodinyMax')
            ->setCode('col-hodinymax')
            ->setHeaderText('Prekroceno') ->setFormat('number1') ->setAlign('center') ->setOrdering(true);
    }


    function setFilterForm()
    {
        parent::setFilterForm();
        $this->filterForm->osobyFiltr = 'PracovniPomer.ZpracovatDochazku = 1';
        $this ->filterForm ->downloadFotoOsobyUrl = '?menuid=editace&action=foto&idpp=';
        $this ->filterForm ->nastavAkciGet('omezenidochazky');
    }


    function load($sqlFilter = '')
    {
        parent::load($sqlFilter);
        $this ->browserUrl =
            '?menuid=omezenidochazky&idpp=' . (int)$this ->filterForm ->vybranaOsoba . '&obdobi=' . DateUtils::dateToUrlString($this ->filterForm ->vybraneObdobiOd);
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        $result = $this ->filterForm ->buildSqlFilter($params);

        return new SqlStatement(
            $result .
            ($result ? ' AND ' : '') .
            ' RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND DatumNastupu = ' . $params ->addDateParameter($this ->filterForm ->vybranaOsobaDatumNastupu) .
            ' AND PocatekObdobi <= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiDo) .
            ' AND KonecObdobi >= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiOd),
            $params);
    }

}
